@@ -1,3 +1,5 @@
+File.expand_path('../../../../openstacklib/lib', File.dirname(__FILE__)).tap { |dir| $LOAD_PATH.unshift(dir) unless $LOAD_PATH.include?(dir) }
+
 require 'puppet/util/inifile'
 require 'puppet/provider/openstack'
 require 'puppet/provider/openstack/auth'
@@ -32,13 +34,11 @@ class Puppet::Provider::Cinder < Puppet::Provider::Openstack
     @credentials.password = cinder_credentials['password']
     @credentials.project_name = cinder_credentials['project_name']
     @credentials.auth_url = auth_endpoint
+    @credentials.user_domain_name = cinder_credentials['user_domain_name']
+    @credentials.project_domain_name = cinder_credentials['project_domain_name']
     if cinder_credentials['region_name']
       @credentials.region_name = cinder_credentials['region_name']
     end
-    if @credentials.version == '3'
-      @credentials.user_domain_name = cinder_credentials['user_domain_name']
-      @credentials.project_domain_name = cinder_credentials['project_domain_name']
-    end
     raise error unless @credentials.set?
     Puppet::Provider::Openstack.request(service, action, properties, @credentials)
   end
@@ -52,26 +52,29 @@ class Puppet::Provider::Cinder < Puppet::Provider::Openstack
   end
 
   def self.get_cinder_credentials
-    auth_keys = ['auth_uri', 'project_name', 'username',
+    auth_keys = ['auth_url', 'project_name', 'username',
                  'password']
     conf = cinder_conf
     if conf and conf['keystone_authtoken'] and
         auth_keys.all?{|k| !conf['keystone_authtoken'][k].nil?}
       creds = Hash[ auth_keys.map \
                    { |k| [k, conf['keystone_authtoken'][k].strip] } ]
-      if conf['project_domain_name']
-        creds['project_domain_name'] = conf['project_domain_name']
+      if conf['keystone_authtoken']['project_domain_name']
+        creds['project_domain_name'] = conf['keystone_authtoken']['project_domain_name']
       else
         creds['project_domain_name'] = 'Default'
       end
-      if conf['user_domain_name']
-        creds['user_domain_name'] = conf['user_domain_name']
+
+      if conf['keystone_authtoken']['user_domain_name']
+        creds['user_domain_name'] = conf['keystone_authtoken']['user_domain_name']
       else
         creds['user_domain_name'] = 'Default'
       end
-      if conf['DEFAULT'] and conf['DEFAULT']['os_region_name']
-        creds['region_name'] = conf['DEFAULT']['os_region_name']
+
+      if conf['keystone_authtoken']['region_name']
+        creds['region_name'] = conf['keystone_authtoken']['region_name']
       end
+
       return creds
     else
       raise(Puppet::Error, "File: #{conf_filename} does not contain all " +
@@ -82,7 +85,7 @@ class Puppet::Provider::Cinder < Puppet::Provider::Openstack
 
   def self.get_auth_endpoint
     q = cinder_credentials
-    "#{q['auth_uri']}"
+    "#{q['auth_url']}"
   end
 
   def self.auth_endpoint
