@@ -30,11 +30,8 @@ describe 'cinder::api' do
         is_expected.to contain_cinder_config('DEFAULT/public_endpoint').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/osapi_volume_base_URL').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/osapi_max_limit').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('DEFAULT/os_region_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/auth_strategy').with_value('keystone')
-        is_expected.to contain_cinder_config('key_manager/backend').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('barbican/barbican_endpoint').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('barbican/auth_endpoint').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('DEFAULT/use_forwarded_for').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/osapi_volume_listen_port').with('value' => '<SERVICE DEFAULT>')
 
         is_expected.to contain_oslo__middleware('cinder_config').with(
@@ -44,17 +41,6 @@ describe 'cinder::api' do
       end
     end
 
-    context 'with a custom region for nova' do
-      let :params do
-        req_params.merge({'os_region_name' => 'MyRegion'})
-      end
-      it 'should configure the region for nova' do
-        is_expected.to contain_cinder_config('DEFAULT/os_region_name').with(
-          :value => 'MyRegion'
-        )
-      end
-    end
-
     context 'with a customized port' do
       let :params do
         req_params.merge({'osapi_volume_listen_port' => 9999})
@@ -132,16 +118,6 @@ describe 'cinder::api' do
       )}
     end
 
-    context 'with encryption_auth_url' do
-      let :params do
-        req_params.merge({ :keymgr_encryption_auth_url => 'http://localhost:5000/v3' })
-      end
-
-      it { is_expected.to contain_cinder_config('barbican/auth_endpoint').with(
-        :value => 'http://localhost:5000/v3'
-      )}
-    end
-
     context 'while validating the service with default command' do
       let :params do
         req_params.merge({
@@ -150,7 +126,7 @@ describe 'cinder::api' do
       end
       it { is_expected.to contain_openstacklib__service_validation('cinder-api').with(
         :command   => 'cinder --os-auth-url http://localhost:5000 --os-project-name services --os-username cinder --os-password foo list',
-        :subscribe => 'Service[cinder-api]',
+        :subscribe => 'Anchor[cinder::service::end]',
       )}
     end
 
@@ -165,6 +141,17 @@ describe 'cinder::api' do
       end
     end
 
+    context 'with a custom use_forwarded_for' do
+      let :params do
+        req_params.merge({'use_forwarded_for' => true})
+      end
+      it 'should configure the osapi_max_limit to 10000' do
+        is_expected.to contain_cinder_config('DEFAULT/use_forwarded_for').with(
+          :value => true
+        )
+      end
+    end
+
     context 'with a custom osapi_max_limit' do
       let :params do
         req_params.merge({'osapi_max_limit' => '10000'})
@@ -175,6 +162,7 @@ describe 'cinder::api' do
         )
       end
     end
+
     context 'when running cinder-api in wsgi' do
       let :params do
         req_params.merge!({ :service_name => 'httpd' })
@@ -239,22 +227,6 @@ describe 'cinder::api' do
 
       it_raises 'a Puppet::Error', /The cert_file parameter is required when use_ssl is set to true/
     end
-
-    context 'with barbican parameters' do
-      let :params do
-        req_params.merge!({
-          :keymgr_backend             => 'barbican',
-          :keymgr_encryption_api_url  => 'https://localhost:9311/v1',
-          :keymgr_encryption_auth_url => 'https://localhost:5000/v3',
-        })
-      end
-      it 'should set keymgr parameters' do
-        is_expected.to contain_cinder_config('key_manager/backend').with_value('barbican')
-        is_expected.to contain_cinder_config('barbican/barbican_endpoint').with_value('https://localhost:9311/v1')
-        is_expected.to contain_cinder_config('barbican/auth_endpoint').with_value('https://localhost:5000/v3')
-      end
-    end
-
   end
 
   on_supported_os({
